diff lisp/bytecomp.el @ 416:ebe98a74bd68 r21-2-16

Import from CVS: tag r21-2-16
author cvs
date Mon, 13 Aug 2007 11:22:23 +0200
parents 697ef44129c6
children
line wrap: on
line diff
--- a/lisp/bytecomp.el	Mon Aug 13 11:21:40 2007 +0200
+++ b/lisp/bytecomp.el	Mon Aug 13 11:22:23 2007 +0200
@@ -1747,7 +1747,7 @@
   ;; file if under Mule.  If there are any extended characters in the
   ;; input file, use `escape-quoted' to make sure that both binary and
   ;; extended characters are output properly and distinguished properly.
   ;; Otherwise, use `no-conversion' for maximum portability with non-Mule
   ;; Emacsen.
   (when (featurep 'mule)
     (defvar buffer-file-coding-system)
@@ -1758,7 +1758,7 @@
 	  (skip-chars-forward (concat (char-to-string 0) "-"
 				      (char-to-string 255)))
 	  (eq (point) (point-max)))
-	(setq buffer-file-coding-system 'no-conversion)
+	(setq buffer-file-coding-system 'raw-text)
       (insert "(require 'mule)\n;;;###coding system: escape-quoted\n")
       (setq buffer-file-coding-system 'escape-quoted)
       ;; #### Lazy loading not yet implemented for MULE files
@@ -1747,7 +1747,7 @@
   ;; input file, use `escape-quoted' to make sure that both binary and
   ;; extended characters are output properly and distinguished properly.
-  ;; Otherwise, use `no-conversion' for maximum portability with non-Mule
+  ;; Otherwise, use `raw-text' for maximum portability with non-Mule
   ;; Emacsen.
   (when (featurep 'mule)